@@ -17,8 +17,8 @@
 #ifndef AVOGADRO_MOLEQUEUE_INPUTGENERATOR_H
 #define AVOGADRO_MOLEQUEUE_INPUTGENERATOR_H
 
-#include <QtCore/QObject>
 #include "avogadromolequeueexport.h"
+#include <QtCore/QObject>
 
 #include <avogadro/core/avogadrocore.h>
 
@@ -214,16 +214,23 @@ namespace MoleQueue {
  * consistent interface and ensure that MoleQueue job staging uses correct
  * values where appropriate.
  *
- * | Option name        | type       | description                                                         |
- * | :----------------: | :--------: | :------------------------------------------------------------------ |
- * | "Title"            | string     | Input file title comment, MoleQueue job description.                |
- * | "Filename Base"    | string     | Input file base name, e.g. "job" in "job.inp".                      |
- * | "Processor Cores"  | integer    | Number of cores to use. Will be passed to MoleQueue.                |
- * | "Calculation Type" | stringList | Type of calculation, e.g. "Single Point" or "Equilibrium Geometry". |
- * | "Theory"           | stringList | Levels of QM theory, e.g. "RHF", "B3LYP", "MP2", "CCSD", etc.       |
- * | "Basis"            | stringList | Available basis sets, e.g. "STO-3G", "6-31G**", etc.                |
- * | "Charge"           | integer    | Charge on the system.                                               |
- * | "Multiplicity"     | integer    | Spin multiplicity of the system.                                    |
+ * | Option name        | type       | description |
+ * | :----------------: | :--------: |
+:------------------------------------------------------------------ |
+ * | "Title"            | string     | Input file title comment, MoleQueue job
+description.                |
+ * | "Filename Base"    | string     | Input file base name, e.g. "job" in
+"job.inp".                      |
+ * | "Processor Cores"  | integer    | Number of cores to use. Will be passed to
+MoleQueue.                |
+ * | "Calculation Type" | stringList | Type of calculation, e.g. "Single Point"
+or "Equilibrium Geometry". |
+ * | "Theory"           | stringList | Levels of QM theory, e.g. "RHF", "B3LYP",
+"MP2", "CCSD", etc.       |
+ * | "Basis"            | stringList | Available basis sets, e.g. "STO-3G",
+"6-31G**", etc.                |
+ * | "Charge"           | integer    | Charge on the system. |
+ * | "Multiplicity"     | integer    | Spin multiplicity of the system. |
  *
  * Syntax Highlighting
  * -------------------
@@ -456,10 +463,10 @@ public:
    * Constructor
    * @param scriptFilePath_ Absolute path to generator script.
    */
-  explicit InputGenerator(const QString &scriptFilePath_,
-                          QObject *parent_ = NULL);
-  explicit InputGenerator(QObject *parent_ = NULL);
-  ~InputGenerator();
+  explicit InputGenerator(const QString& scriptFilePath_,
+                          QObject* parent_ = nullptr);
+  explicit InputGenerator(QObject* parent_ = nullptr);
+  ~InputGenerator() override;
 
   /**
    * @return True if debugging is enabled.
@@ -501,7 +508,7 @@ public:
    * Set the path to the input generator script file. This will reset any
    * cached data held by this class.
    */
-  void setScriptFilePath(const QString &scriptFile);
+  void setScriptFilePath(const QString& scriptFile);
 
   /**
    * Clear any cached data and return to an uninitialized state.
@@ -521,7 +528,7 @@ public:
    * to check for success, and errorString() or errorList() to get a
    * user-friendly description of the error.
    */
-  bool generateInput(const QJsonObject &options_, const Core::Molecule &mol);
+  bool generateInput(const QJsonObject& options_, const Core::Molecule& mol);
 
   /**
    * @return The number of input files stored by generateInput().
@@ -551,15 +558,16 @@ public:
    * generateInput() first.
    * @sa fileNames
    */
-  QString fileContents(const QString &fileName) const;
+  QString fileContents(const QString& fileName) const;
 
   /**
    * @return A syntax highlighter for the file @a fileName. Must call
    * generateInput() first. The caller takes ownership of the returned object.
-   * If no syntax highlighter is defined, this function returns NULL.
+   * If no syntax highlighter is defined, this function returns nullptr.
    * @sa fileNames
    */
-  QtGui::GenericHighlighter *createFileHighlighter(const QString &fileName) const;
+  QtGui::GenericHighlighter* createFileHighlighter(
+    const QString& fileName) const;
 
   /**
    * @return True if an error is set.
@@ -591,21 +599,22 @@ public slots:
   void setDebug(bool d);
 
 private:
-  QtGui::PythonScript *m_interpreter;
+  QtGui::PythonScript* m_interpreter;
 
   void setDefaultPythonInterpretor();
-  QByteArray execute(const QStringList &args,
-                     const QByteArray &scriptStdin = QByteArray()) const;
-  bool parseJson(const QByteArray &json, QJsonDocument &doc) const;
-  QString processErrorString(const QProcess &proc) const;
-  bool insertMolecule(QJsonObject &json, const Core::Molecule &mol) const;
-  QString generateCoordinateBlock(const QString &spec,
-                                  const Core::Molecule &mol) const;
-  void replaceKeywords(QString &str, const Core::Molecule &mol) const;
-  bool parseHighlightStyles(const QJsonArray &json) const;
-  bool parseRules(const QJsonArray &json, QtGui::GenericHighlighter &highligher) const;
-  bool parseFormat(const QJsonObject &json, QTextCharFormat &format) const;
-  bool parsePattern(const QJsonValue &json, QRegExp &pattern) const;
+  QByteArray execute(const QStringList& args,
+                     const QByteArray& scriptStdin = QByteArray()) const;
+  bool parseJson(const QByteArray& json, QJsonDocument& doc) const;
+  QString processErrorString(const QProcess& proc) const;
+  bool insertMolecule(QJsonObject& json, const Core::Molecule& mol) const;
+  QString generateCoordinateBlock(const QString& spec,
+                                  const Core::Molecule& mol) const;
+  void replaceKeywords(QString& str, const Core::Molecule& mol) const;
+  bool parseHighlightStyles(const QJsonArray& json) const;
+  bool parseRules(const QJsonArray& json,
+                  QtGui::GenericHighlighter& highligher) const;
+  bool parseFormat(const QJsonObject& json, QTextCharFormat& format) const;
+  bool parsePattern(const QJsonValue& json, QRegExp& pattern) const;
 
   // File extension of requested molecule format
   mutable QString m_moleculeExtension;
@@ -620,7 +629,6 @@ private:
   QMap<QString, QtGui::GenericHighlighter*> m_fileHighlighters;
 
   mutable QMap<QString, QtGui::GenericHighlighter*> m_highlightStyles;
-
 };
 
 inline bool InputGenerator::isValid() const
